#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

/**/

#include "Common.h"

/**/

extern unsigned short gMainWinHeight;

//----------------------------------------------------------
//Function for the event procedure
//----------------------------------------------------------
void MainWinFixSize(WSCbase* object){
  //do something...
	unsigned short h = object->getProperty( WSNheight );

	if( h > gMainWinHeight )
		object->setProperty( WSNheight, gMainWinHeight );
}
static WSCfunctionRegister  op("MainWinFixSize",(void*)MainWinFixSize);
